@@ -28,13 +28,12 @@ import java.util.HashSet;
 import java.util.concurrent.ConcurrentHashMap;
 
 import javax.jbi.JBIException;
-import javax.management.StandardMBean;
+import javax.management.MBeanServer;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.jbi.deployer.Component;
 import org.apache.servicemix.jbi.deployer.DeployedAssembly;
-import org.apache.servicemix.jbi.deployer.NamingStrategy;
 import org.apache.servicemix.jbi.deployer.ServiceAssembly;
 import org.apache.servicemix.jbi.deployer.SharedLibrary;
 import org.apache.servicemix.jbi.deployer.ServiceUnit;
@@ -58,6 +57,7 @@ import org.apache.servicemix.jbi.runtime.ComponentWrapper;
 import org.apache.servicemix.jbi.runtime.Environment;
 import org.apache.servicemix.nmr.api.event.ListenerRegistry;
 import org.apache.servicemix.nmr.core.ListenerRegistryImpl;
+import org.fusesource.commons.management.ManagementStrategy;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
@@ -68,14 +68,11 @@ import org.osgi.service.prefs.Preferences;
 import org.osgi.service.prefs.PreferencesService;
 import org.osgi.util.tracker.ServiceTracker;
 import org.springframework.osgi.util.OsgiStringUtils;
-import org.springframework.osgi.context.BundleContextAware;
-import org.springframework.beans.factory.InitializingBean;
-import org.springframework.beans.factory.DisposableBean;
 
 /**
  * Deployer for JBI artifacts
  */
-public class Deployer implements BundleContextAware, InitializingBean, DisposableBean, SynchronousBundleListener, LifeCycleListener {
+public class Deployer implements SynchronousBundleListener, LifeCycleListener {
 
     public static final String NAME = "NAME";
     public static final String TYPE = "TYPE";
@@ -118,15 +115,16 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
     private int shutdownTimeout;
 
     // Helper beans
-    private NamingStrategy namingStrategy;
-    private ManagementAgent managementAgent;
+    private ManagementStrategy managementStrategy;
     private Environment environment;
 
     private ListenerRegistry listenerRegistry;
+    
+    private MBeanServer mbeanServer;
 
     public Deployer() throws JBIException {
         // TODO: control that using properties
-        jbiRootDir = new File(System.getProperty("servicemix.base"), "data/jbi");
+        jbiRootDir = new File(System.getProperty("karaf.base"), "data/jbi");
         jbiRootDir.mkdirs();
         // Create listener registry
         listenerRegistry = new ListenerRegistryImpl();
@@ -165,20 +163,20 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
         return endpointListener;
     }
 
-    public NamingStrategy getNamingStrategy() {
-        return namingStrategy;
+    public ManagementStrategy getManagementStrategy() {
+        return managementStrategy;
     }
 
-    public void setNamingStrategy(NamingStrategy namingStrategy) {
-        this.namingStrategy = namingStrategy;
+    public void setManagementStrategy(ManagementStrategy managementStrategy) {
+        this.managementStrategy = managementStrategy;
+    }
+    
+    public MBeanServer getMbeanServer() {
+        return mbeanServer;
     }
 
-    public ManagementAgent getManagementAgent() {
-        return managementAgent;
-    }
-
-    public void setManagementAgent(ManagementAgent managementAgent) {
-        this.managementAgent = managementAgent;
+    public void setMbeanServer(MBeanServer mbeanServer) {
+        this.mbeanServer = mbeanServer;
     }
 
     public void setEnvironment(Environment environment) {
@@ -229,7 +227,7 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
         return shutdownTimeout;
     }
 
-    public void afterPropertiesSet() throws Exception {
+    public void init() throws Exception {
         // Track bundles
         bundleContext.addBundleListener(this);
         for (Bundle bundle : bundleContext.getBundles()) {
@@ -404,7 +402,7 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
         return new ServiceUnitImpl(sud, suRootDir, component);
     }
 
-    public SharedLibrary registerSharedLibrary(Bundle bundle, SharedLibraryDesc sharedLibraryDesc, ClassLoader classLoader) throws Exception {
+    public SharedLibraryImpl registerSharedLibrary(Bundle bundle, SharedLibraryDesc sharedLibraryDesc, ClassLoader classLoader) throws Exception {
         // Create shared library
         SharedLibraryImpl sl = new SharedLibraryImpl(bundle, sharedLibraryDesc, classLoader);
         sharedLibraries.put(sl.getName(), sl);
@@ -413,13 +411,13 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
         props.put(NAME, sharedLibraryDesc.getIdentification().getName());
         LOGGER.debug("Registering JBI Shared Library");
         registerService(bundle, SharedLibrary.class.getName(), sl, props);
-        getManagementAgent().register(new StandardMBean(sl, SharedLibrary.class), getNamingStrategy().getObjectName(sl));
+        getManagementStrategy().manageObject(sl);
         // Check pending bundles
         checkPendingInstallers();
         return sl;
     }
 
-    public Component registerComponent(Bundle bundle, ComponentDesc componentDesc, javax.jbi.component.Component innerComponent, SharedLibrary[] sharedLibraries) throws Exception {
+    public ComponentImpl registerComponent(Bundle bundle, ComponentDesc componentDesc, javax.jbi.component.Component innerComponent, SharedLibrary[] sharedLibraries) throws Exception {
         String name = componentDesc.getIdentification().getName();
         Preferences prefs = preferencesService.getUserPreferences(name);
         ComponentImpl component = new ComponentImpl(bundle, componentDesc, innerComponent, prefs, autoStart, sharedLibraries);
@@ -440,12 +438,11 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
         if (!wrappedComponents.containsKey(name)) {
             registerService(bundle, javax.jbi.component.Component.class.getName(), innerComponent, props);
         }
-        getManagementAgent().register(new StandardMBean(component, Component.class),
-                                      getNamingStrategy().getObjectName(component));
+        getManagementStrategy().manageObject(component);
         return component;
     }
 
-    public ServiceAssembly registerServiceAssembly(Bundle bundle, ServiceAssemblyDesc serviceAssemblyDesc, List<ServiceUnitImpl> sus) throws Exception {
+    public ServiceAssemblyImpl registerServiceAssembly(Bundle bundle, ServiceAssemblyDesc serviceAssemblyDesc, List<ServiceUnitImpl> sus) throws Exception {
         // Now create the SA and initialize it
         Preferences prefs = preferencesService.getUserPreferences(serviceAssemblyDesc.getIdentification().getName());
         ServiceAssemblyImpl sa = new ServiceAssemblyImpl(bundle, serviceAssemblyDesc, sus, prefs, endpointListener, autoStart);
@@ -459,7 +456,7 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
         // register the service assembly in the OSGi registry
         LOGGER.debug("Registering JBI service assembly");
         registerService(bundle, ServiceAssembly.class.getName(), sa, props);
-        getManagementAgent().register(new StandardMBean(sa, ServiceAssembly.class), getNamingStrategy().getObjectName(sa));
+        getManagementStrategy().manageObject(sa);
         return sa;
     }
 
@@ -604,6 +601,14 @@ public class Deployer implements BundleContextAware, InitializingBean, Disposabl
                     break;
             }
         }
+
+        // propagate lifecycle event to management strategy
+        // 
+        try {
+            getManagementStrategy().notify(event);
+        } catch (Exception e) {
+            // ignore
+        }
     }
 
     //===============================================================================
