@@ -16,23 +16,22 @@
  */
 package org.apache.servicemix.nmr.core;
 
+import org.apache.camel.impl.DefaultClassResolver;
+import org.apache.camel.impl.DefaultFactoryFinderResolver;
+import org.apache.camel.impl.DefaultPackageScanClassResolver;
 import org.apache.camel.impl.converter.DefaultTypeConverter;
 import org.apache.camel.util.ReflectionInjector;
-import org.apache.camel.NoTypeConversionAvailableException;
 
 /**
  * A converter using Camel underneath
  */
 class CamelConverter implements Converter {
 
-    final DefaultTypeConverter tc = new DefaultTypeConverter(new ReflectionInjector());
+    final DefaultTypeConverter tc = new DefaultTypeConverter(new DefaultPackageScanClassResolver(),
+        new ReflectionInjector(), new DefaultFactoryFinderResolver().resolveDefaultFactoryFinder(new DefaultClassResolver()));
 
     public <T> T convert(Object body, Class<T> type) {
-        try {
-            return tc.convertTo(type, body);
-        } catch (NoTypeConversionAvailableException e) {
-            return null;
-        }
+        return tc.convertTo(type, body);
     }
 
 }
